##################################################
#
# table
# Module | Table
# 
# Displays an indexed, structured, table 
# representing a given Resource's content.
#
# Daniel Bakas Amuchastegui
# September 3, 2019
# 
# Copyright © Semantyk 2020. All rights reserved.
##################################################


##################################################
#
# cell
# Package | Cell
# 
# Package containing the main components of a 
# cell.
#
# Daniel Bakas Amuchastegui
# February, 2020
# 
# Copyright © Semantyk 2020. All rights reserved.
##################################################

from . import cell
from . import dvm_extract_cell
from . import multimedia_cell
from . import text_cell

from .cell import *
from .dvm_extract_cell import *
from .multimedia_cell import *
from .text_cell import *


##################################################
#
# venn_diagram
# Module | Venn Diagram
# 
# Diagram that displays all possible logical 
# relations between a finite collection of 
# different resources.
#
# Daniel Bakas Amuchastegui
# September 3, 2019
# 
# Copyright © Semantyk 2020. All rights reserved.
##################################################


##################################################
#
# uuid_generator
# Module | UUID Generator
#
# Daniel Bakas Amuchastegui
# March 16, 2020
# 
# Copyright © Semantyk 2020. All rights reserved.
##################################################

import uuid

def generate_uuid():
    result = '0'
    while result[0] not in {'a', 'b', 'c', 'd', 'e', 'f'}:
        result = uuid.uuid4().hex
        result = result[0:8] + '_' + result[8:12] + '_' + result[12:16] + '_' + result[16:20] + '_' + result[20:]
    return result


##################################################
#
# core
# Package | Core
#
# Author: Daniel Bakas Amuchastegui
# March 16, 2020
# 
# Copyright © Semantyk 2020. All rights reserved.
##################################################

from . import graph
from . import model
from . import resource

from .graph import *
from .model import *
from .resource import *


from setuptools import find_packages, setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name = "semantyk",
    version = "0.0.0.38",
    author = "Daniel Bakas Amuchastegui",
    maintainer = "Semantyk Team",
    description = "Ideas Wonder.",
    long_description = long_description,
    long_description_content_type = "text/markdown",
    url = "https://github.com/semantykcom/Semantyk",
    packages = find_packages(
        exclude = [
            'docs',
            'tests*'
        ]
    ),
    classifiers = [
        "Development Status :: 1 - Planning",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3"
    ],
    install_requires = [
        'rdflib'
    ],
    python_requires = '>=3.6',
    keywords = 'semantyk'
)